"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var mapboxgl_1 = require("../utils/mapboxgl");
/** These methods may break the react binding if called directly */
var skipMethods = [
    'setMaxBounds',
    'setMinZoom',
    'setMaxZoom',
    'setMinPitch',
    'setMaxPitch',
    'setRenderWorldCopies',
    'setProjection',
    'setStyle',
    'addSource',
    'removeSource',
    'addLayer',
    'removeLayer',
    'setLayerZoomRange',
    'setFilter',
    'setPaintProperty',
    'setLayoutProperty',
    'setLight',
    'setTerrain',
    'setFog',
    'remove'
];
function createRef(mapInstance) {
    if (!mapInstance) {
        return null;
    }
    var map = mapInstance.map;
    var result = {
        getMap: function () { return map; },
        // Overwrite getters to use our shadow transform
        getCenter: function () { return mapInstance.transform.center; },
        getZoom: function () { return mapInstance.transform.zoom; },
        getBearing: function () { return mapInstance.transform.bearing; },
        getPitch: function () { return mapInstance.transform.pitch; },
        getPadding: function () { return mapInstance.transform.padding; },
        getBounds: function () { return mapInstance.transform.getBounds(); },
        project: function (lnglat) {
            return mapInstance.transform.locationPoint(mapboxgl_1.default.LngLat.convert(lnglat));
        },
        unproject: function (point) {
            return mapInstance.transform.pointLocation(mapboxgl_1.default.Point.convert(point));
        }
    };
    for (var _i = 0, _a = getMethodNames(map); _i < _a.length; _i++) {
        var key = _a[_i];
        // @ts-expect-error
        if (!(key in result) && !skipMethods.includes(key)) {
            result[key] = map[key].bind(map);
        }
    }
    return result;
}
exports.default = createRef;
function getMethodNames(obj) {
    var result = new Set();
    var proto = obj;
    while (proto) {
        for (var _i = 0, _a = Object.getOwnPropertyNames(proto); _i < _a.length; _i++) {
            var key = _a[_i];
            if (key[0] !== '_' &&
                typeof obj[key] === 'function' &&
                key !== 'fire' &&
                key !== 'setEventedParent') {
                result.add(key);
            }
        }
        proto = Object.getPrototypeOf(proto);
    }
    return Array.from(result);
}
//# sourceMappingURL=create-ref.js.map