import { useContext, useMemo, useEffect } from 'react';
import { MapContext } from './map';
export default function useControl(onCreate, opts) {
    const map = useContext(MapContext);
    const ctrl = useMemo(onCreate, []);
    useEffect(() => {
        if (map) {
            map.addControl(ctrl, opts?.position);
            opts?.onAdd?.(map);
            return () => {
                opts?.onRemove?.(map);
                // Map might have been removed (parent effects are destroyed before child ones)
                if (map.hasControl(ctrl)) {
                    map.removeControl(ctrl);
                }
            };
        }
        return undefined;
    }, [map]);
    return ctrl;
}
//# sourceMappingURL=use-control.js.map